@@ -3,6 +3,8 @@
 #ifndef __LXC_STATE_H
 #define __LXC_STATE_H
 
+#include "config.h"
+
 #include "compiler.h"
 
 #define MAX_STATE_LENGTH (8 + 1)
@@ -25,7 +27,7 @@ enum {
 	REBOOT_INIT
 };
 
-__hidden extern lxc_state_t lxc_getstate(const char *name, const char *lxcpath);
+__hidden extern lxc_state_t lxc_getstate(const char *name, const char *lxcpath, int timeout);
 
 __hidden extern lxc_state_t lxc_str2state(const char *state);
 __hidden extern const char *lxc_state2str(lxc_state_t state);
