@@ -81,7 +81,7 @@ int dir_create(struct lxc_storage *bdev, const char *dest, const char *n,
 	if (!bdev_dest)
 		return ret_errno(ENOMEM);
 
-	ret = mkdir_p(dest, 0755);
+	ret = lxc_mkdir_p(dest, 0755);
 	if (ret < 0)
 		return log_error_errno(-errno, errno, "Failed to create directory \"%s\"", dest);
 
