@@ -1,9 +1,7 @@
 /* SPDX-License-Identifier: GPL-2.0-only */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE 1
-#endif
-#include <dirent.h>
+#include "config.h"
+
 #include <getopt.h>
 #include <limits.h>
 #include <regex.h>
@@ -19,10 +17,9 @@
 #include <termios.h>
 #include <unistd.h>
 
-#include <lxc/lxccontainer.h>
+#include "lxc.h"
 
 #include "arguments.h"
-#include "config.h"
 #include "log.h"
 #include "memory_utils.h"
 #include "utils.h"
@@ -189,9 +186,12 @@ Options :\n\
 	.options = my_longopts,
 	.parser = my_parser,
 	.ls_nesting = 0,
+	.log_priority = "ERROR",
+	.log_file     = "none",
 };
 
-int main(int argc, char *argv[])
+int __attribute__((weak, alias("lxc_ls_main"))) main(int argc, char *argv[]);
+int lxc_ls_main(int argc, char *argv[])
 {
 	int ret = EXIT_FAILURE;
 	struct lxc_log log;
