@@ -1,24 +1,11 @@
 /* liblxcapi
  *
- * Copyright © 2013 Oracle.
+ * SPDX-License-Identifier: GPL-2.0-only
  *
- * Authors:
- * Dwight Engen <dwight.engen@oracle.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2, as
- * published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "config.h"
+
 #include <errno.h>
 #include <string.h>
 #include <unistd.h>
@@ -32,8 +19,8 @@
 
 #include <lxc/lxccontainer.h>
 
-#ifndef HAVE_STRLCPY
-#include "include/strlcpy.h"
+#if !HAVE_STRLCPY
+#include "strlcpy.h"
 #endif
 
 #define TSTNAME    "lxc-attach-test"
